import { useObserver } from 'mobx-react-lite';
import React from 'react';
import { Grow } from '../Atoms';
import { DocsCollection } from '../DocsCollection';
import { DocsLoadingPlaceholder } from '../DocsCollection/DocsLoadingPlaceholder';
import { DocsHeader } from '../DocsHeader';
import { PageAction } from '../PageAction';
import { PageContent } from '../PageContent';
import { PageTitle } from '../PageTitle';
import { extractAnyUiElements } from '../utils';
import { InjectEmptyResultSlotContent } from './components/DocsEmptyResultSlot';
import { InjectLoadingSlotContent } from './components/DocsLoading';
import { DocsSlotsProvider } from './components/DocsSlotsProvider';
export const DocsLayout = ({ collection, children, pageWidth, }) => {
    const [remainingChildren, elements] = extractAnyUiElements(children, [
        PageAction,
        PageTitle,
        DocsCollection,
    ]);
    return useObserver(() => {
        const isLoading = collection.isLoading;
        const hasData = collection.hasDocs;
        return (React.createElement(DocsSlotsProvider, null,
            React.createElement(PageContent, { width: pageWidth },
                React.createElement(DocsHeader, { gutterBottom: true },
                    elements.get(PageTitle),
                    React.createElement(Grow, null),
                    elements.get(PageAction)),
                isLoading ? (React.createElement(InjectLoadingSlotContent, null,
                    React.createElement(DocsLoadingPlaceholder, { count: 3 }))) : !hasData ? (React.createElement(InjectEmptyResultSlotContent, null)) : (elements.get(DocsCollection)),
                remainingChildren)));
    });
};
export default DocsLayout;
