# Dialog

### `useDialog`

React hook to make using Dialogs super simple.

### Params

- `startOpen` optional boolean: starts the dialog opened

### Returns

Returns an object with the following properties:

- `isOpen`: open state of the Dialog, true/false
- `openDialog`: function to open the Dialog
- `closeDialog` function to close the Dialog
- `Dialog`: Managed Dialog component to use

### Dialog Props

- `title`: optional title for Dialog
- `confirmAction` optional, one of:
  - `string`: Label for confirm button
  - `false`: no confirm action automatically generated

### Example

```typescript jsx
import { useDialog } from '@any-ui/core'
import { Button, DialogContent } from '@material-ui/core'
import React, { FC } from 'react'

export const OpenDialogButton: FC = () => {
  const { openDialog, Dialog } = useDialog()
  return (
    <>
      <Dialog title="Example Dialog" confirmAction="Create Link">
        <DialogContent>
          Anyone with this link can view all data about this site and it's users
          without a login. Create link?
        </DialogContent>
      </Dialog>
      <Button onClick={openDialog}>Example Dialog</Button>
    </>
  )
}
```
