import type { SvgIconProps } from "@material-ui/core/SvgIcon";
import flatten from "lodash/flatten";
import React, {
  Children,
  ComponentType,
  FC,
  FunctionComponentElement,
  ReactNode
} from "react";
import { isAnyUiElement, NamedAnyUiComponent } from "../utils";

export interface IAction {
  onClick: () => void;
  label: string;
  Icon: ComponentType<SvgIconProps>;
}

export const Action: FC<IAction> = () => null;

export type BadgeValue = () => number;

export interface IPathAction {
  badge?: BadgeValue;
  path: string;
  root?: boolean;
  exact?: boolean;
  label?: React.ReactNode;
  Icon: ComponentType<SvgIconProps>;
}

export const PathAction: NamedAnyUiComponent<IPathAction> = () => null;
PathAction.anyUiName = "PathAction";
export default PathAction;

export const extractPathActions = (
  children: ReactNode,
  Component: NamedAnyUiComponent<IPathAction>,
  propsMapper: (props: any) => any = props => props
) =>
  flatten(
    Children.map(children, c => {
      if (c && isAnyUiElement(c, PathAction)) {
        return [React.createElement(Component, propsMapper(c.props))];
      }
      return [] as Array<FunctionComponentElement<IPathAction>>;
    })
  );

export const mapPathActions = (
  children: ReactNode,
  Component: NamedAnyUiComponent<IPathAction>,
  propsMapper: (props: any) => any = props => props
) =>
  Children.map(children, c => {
    if (c && isAnyUiElement(c, PathAction)) {
      return React.createElement(Component, propsMapper(c.props));
    }
    return c;
  });
