import clsx from 'clsx'
import React, { FC } from 'react'
import AppBar from '../AppBar'
import { FlexRoot, FullHeight } from '../Atoms'
import { DrawerLayout, DrawerProvider } from '../DrawerLayout'
import { BottomNav, TopNav } from '../PrimaryNav'
import { ResponsiveTitle } from '../ResponsiveTitle'
import { Visible } from '../Visibility'
import { AppBarLogoContent } from './components/AppBarLogoSlot'
import { AppBarMenuContent } from './components/AppBarMenuSlot'
import { AppBarRightContent } from './components/AppBarRightSlot'
import { RenderAppContent } from './components/AppContentSlot'
import { AppSlotsProvider } from './components/AppSlotsProvider'
import { RenderAppTitle } from './components/AppTitleSlot'
import { RenderMobileFab } from './components/MobileFabSlot'

export const AppLayout: FC = ({ children }) => (
  <AppSlotsProvider>
    <DrawerProvider>
      <FlexRoot>
        <AppBar>
          <AppBarMenuContent />
          <AppBarLogoContent />
          <ResponsiveTitle
            className={clsx('AppBarTitle', 'AuiTitle', 'SiteMasthead')}
          >
            <RenderAppTitle />
          </ResponsiveTitle>
          <Visible.Desktop>
            <TopNav centered />
          </Visible.Desktop>
          <AppBarRightContent />
        </AppBar>
        <DrawerLayout appBar />
        <FullHeight appBar bottomNav>
          <RenderAppContent />
          <RenderMobileFab />
          <Visible.Mobile>
            <BottomNav />
          </Visible.Mobile>
        </FullHeight>
      </FlexRoot>
      {children}
    </DrawerProvider>
  </AppSlotsProvider>
)
export default AppLayout
