import Box from '@material-ui/core/Box'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import clsx from 'clsx'
import React, { FC } from 'react'
import addClassNameToProps from '../utils/addClassNameToProps'

// eslint-disable
const useStyles = makeStyles<Theme>(theme => {
  return {
    root: {
      flexGrow: 1,
      height: '100%',
      overflow: 'scroll',
      '--tool-bar-height': `${theme.mixins.sizes.toolbar.height}px`,
      [theme.breakpoints.up('sm')]: {
        '--tool-bar-height': `${theme.mixins.sizes.tabbar.height}px`,
      },
      '--full-height': `calc(100% - var(--tool-bar-height))`,
    },
    bottomNav: {
      [theme.breakpoints.down('md')]: {
        marginBottom: `${theme.mixins.sizes.bottomNav.height}px`,
        height: `calc(var(--full-height) - ${theme.mixins.sizes.bottomNav.height}px)`,
      },
    },
    toolbar: {
      marginTop: 'var(--tool-bar-height)',
      height: 'var(--full-height)',
    },
  }
})

export interface IFullHeightProps {
  appBar?: boolean
  bottomNav?: boolean
}

export const FullHeight: FC<IFullHeightProps> = ({
  appBar,
  bottomNav,
  ...props
}) => {
  const classes = useStyles()
  return (
    <Box
      {...addClassNameToProps(
        {
          ...props,
          className: clsx(classes.root, {
            [classes.toolbar]: appBar,
            [classes.bottomNav]: bottomNav,
          }),
        },
        'FullHeight',
      )}
    />
  )
}
export default FullHeight
