import IconButton, {
  IconButtonClassKey,
  IconButtonProps,
} from '@material-ui/core/IconButton'
import type { Theme } from '@material-ui/core/styles'
import TooltipMui from '@material-ui/core/Tooltip'
import { createStyles } from '@material-ui/core/styles'
import React, { FC } from 'react'
import { withStylesAui } from '../styles'

// TODO: Theme Override
export type CardActionIconButtonClassKey = IconButtonClassKey

// eslint-disable
const styles = (theme: Theme) =>
  createStyles<CardActionIconButtonClassKey, any>({
    root: {
      // color: `#FFF`,
      opacity: 0.25,
      transition: theme.transitions.create('opacity', {
        duration: theme.transitions.duration.short,
      }),
      '&:disabled': {
        opacity: 0.25,
        pointerEvents: 'none',
        backgroundColor: 'transparent',
      },
      '&:disabled:hover': {
        pointerEvents: 'none',
      },
      '&:not(.Mui-disabled):hover': {
        opacity: 1,
      },
    },
    colorPrimary: {
      opacity: 0.5,
    },
    disabled: {
      opacity: 0.2,
    },
    colorInherit: {},
    colorSecondary: {},
    edgeEnd: {},
    edgeStart: {},
    label: {},
    sizeSmall: {},
  })

interface IProps extends Partial<IconButtonProps> {
  tooltip?: string
}

export const CardActionIconButtonBase: FC<IProps> = ({
  tooltip,
  color,
  onClick,
  disabled,
  ...rest
}) => {
  const handleClick = (e: React.MouseEvent<any, MouseEvent>) => {
    if (onClick) {
      e.stopPropagation()
      onClick(e)
    }
  }
  const button = (
    <IconButton
      onClick={handleClick}
      color={color}
      disabled={disabled}
      {...rest}
    />
  )
  return tooltip && !disabled ? (
    <TooltipMui title={tooltip}>{button}</TooltipMui>
  ) : (
    button
  )
}

CardActionIconButtonBase.defaultProps = {
  color: 'default',
}

export const CardActionIconButton = withStylesAui(styles, {
  name: 'CardActionIconButton',
})(CardActionIconButtonBase)
export default CardActionIconButton
