import type { PropTypes } from '@material-ui/core'
import Avatar from '@material-ui/core/Avatar'
import ListItemAvatar, {
  ListItemAvatarProps,
} from '@material-ui/core/ListItemAvatar'
import { fade, Theme } from '@material-ui/core/styles'
import { createStyles } from '@material-ui/core/styles'
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from 'clsx'
import React, { FC } from 'react'
import { withStylesAui } from '../styles'
import { capitalize } from '../utils/helpers'

export type AvatarClassKey =
  | 'icon'
  | 'root'
  | 'colorInherit'
  | 'colorDefault'
  | 'colorPrimary'
  | 'colorSecondary'
  | 'apply'
  | 'inverse'

export type AvatarClasses = Partial<ClassNameMap<AvatarClassKey>>

// eslint-disable
const styles = createStyles((theme: Theme) => ({
  icon: {
    fontWeight: 800,
    height: 32,
    width: 32,
  },
  root: {
    '& .MuiSvgIcon-root': {
      minWidth: 32,
    },
  },
  colorInherit: {},
  colorDefault: {
    '--avatar-color': theme.palette.background.default,
    '--avatar-background-color':
      theme.palette.type === 'light'
        ? theme.palette.grey[400]
        : theme.palette.grey[600],
    '&$inverse': {
      '--avatar-color':
        theme.palette.type === 'light'
          ? theme.palette.grey[400]
          : theme.palette.grey[600],
      '--avatar-background-color': theme.palette.background.default,
    },
  },
  colorPrimary: {
    '--avatar-color': theme.palette.primary.main,
    '--avatar-background-color': fade(
      theme.palette.primary.main,
      theme.palette.action.hoverOpacity,
    ),
    '&$inverse': {
      // '--avatar-color': darken(theme.palette.primary.dark, 0.5),
      // '--avatar-background-color': fade(theme.palette.primary.light, 0.75),
      '--avatar-background-color': fade(
        theme.palette.secondary.main,
        theme.palette.action.hoverOpacity,
      ),
    },
  },
  colorSecondary: {
    '--avatar-color': theme.palette.secondary.main,
    '--avatar-background-color': fade(
      theme.palette.secondary.main,
      theme.palette.action.hoverOpacity,
    ),
    '&$inverse': {
      // '--avatar-color': darken(theme.palette.secondary.dark, 0.5),
      // '--avatar-background-color': fade(theme.palette.secondary.light, 0.75),
      // color: theme.palette.primary.main,
      '--avatar-background-color': fade(
        theme.palette.primary.main,
        theme.palette.action.hoverOpacity,
      ),
    },
  },
  apply: {
    color: 'var(--avatar-color)',
    backgroundColor: 'var(--avatar-background-color)',
  },
  inverse: {
    // backgroundColor: 'var(--avatar-color)',
    // color: 'var(--avatar-background-color)',
  },
}))

type TVariant = 'icon' | 'data'

export interface ICardAvatarProps {
  avatar?: string | number
  variant?: TVariant
  color?: PropTypes.Color
  inverse?: boolean
  classes?: AvatarClasses
}

export const CardAvatarBase: FC<Partial<ListItemAvatarProps> &
  ICardAvatarProps> = ({
  classes = {},
  variant = 'icon',
  children,
  color,
  avatar,
  inverse,
  ...rest
}) => {
  return (
    <ListItemAvatar classes={{ root: classes.root }} {...rest}>
      <Avatar
        classes={{
          colorDefault: clsx(
            classes.icon,
            // @ts-ignore
            classes[`color${capitalize(color)}`],
            {
              // @ts-ignore
              [classes.inverse]: inverse,
            },
            classes.apply,
          ),
        }}
      >
        {avatar || children}
      </Avatar>
    </ListItemAvatar>
  )
}

CardAvatarBase.defaultProps = {
  color: 'default',
}

export const CardAvatar = withStylesAui(styles, {
  name: 'CardAvatar',
})(CardAvatarBase)
export default CardAvatar as React.ComponentType<ICardAvatarProps>

// @ts-ignore
CardAvatar.muiName = ListItemAvatar.muiName
