import Box from '@material-ui/core/Box'
import Fade from '@material-ui/core/Fade'
import Paper from '@material-ui/core/Paper'
import Popper, { PopperProps } from '@material-ui/core/Popper'
import React, { FC } from 'react'
import ConfirmContent from './ConfirmContent'
import type { IConfirmData } from './ConfirmContext'

export const ConfirmPopper: FC<IConfirmData & Partial<PopperProps>> = ({
  anchorEl,
  message,
  onConfirm,
  onCancel,
  title,
  ...rest
}) => {
  return (
    <Popper
      anchorEl={anchorEl}
      open={!!message}
      aria-labelledby={title ? 'confirmation-popper-title' : undefined}
      transition
      placement="bottom-end"
      {...rest}
    >
      {({ TransitionProps }) => (
        <Fade {...TransitionProps} timeout={350}>
          <Box width="450px">
            <Paper elevation={4}>
              <ConfirmContent
                message={message}
                onConfirm={onConfirm}
                onCancel={onCancel}
                title={title}
                titleId="confirmation-popper-title"
              />
            </Paper>
          </Box>
        </Fade>
      )}
    </Popper>
  )
}
export default ConfirmPopper
