import Button, { ButtonProps } from '@material-ui/core/Button'
import React, { FC, KeyboardEvent } from 'react'
import ActionsBar from '../ActionsBar'
import type { ActionsBarProps } from '../ActionsBar/ActionsBar'

export interface IButtonProps extends ButtonProps {
  label?: string
  hide?: boolean
}
export interface IConfirmActionProps {
  buttonProps?: ButtonProps
  confirmProps?: IButtonProps
  cancelProps?: IButtonProps
}

export interface IConfirmActions {
  onConfirm: () => void
  onCancel?: () => void
}
export type IConfirmHandlers = (
  onConfirm: () => void,
  onCancel?: () => void
) => (event: KeyboardEvent<HTMLDivElement>) => void

export const confirmKeyHandlers: IConfirmHandlers = (onConfirm, onCancel) => (
  event: KeyboardEvent<HTMLDivElement>
) => {
  if (event.key === 'Enter') {
    onConfirm()
  }
  if (onCancel && event.key === 'Escape') {
    onCancel()
  }
}

export type ConfirmActionsProps = Partial<IConfirmActions> & IConfirmActionProps & ActionsBarProps
export const ConfirmActions: FC<ConfirmActionsProps> = ({
  onConfirm,
  onCancel,
  buttonProps = { variant: 'contained' },
  confirmProps: {
    hide: hideConfirm,
    label: confirmLabel,
    ...confirmProps
  } = {},
  cancelProps: { hide: hideCancel, label: cancelLabel, ...cancelProps } = {},
  ...rest
}) => (
  <ActionsBar {...rest}>
    {!hideCancel && (
      <Button {...buttonProps} onClick={onCancel} {...cancelProps}>
        {cancelLabel || 'Cancel'}
      </Button>
    )}
    {!hideConfirm && (
      <Button
        color="primary"
        {...buttonProps}
        onClick={onConfirm}
        {...confirmProps}>
        {confirmLabel || 'OK'}
      </Button>
    )}
  </ActionsBar>
)
export default ConfirmActions
