import type { PropTypes } from '@material-ui/core'
import Box from '@material-ui/core/Box'
import ListItem from '@material-ui/core/ListItem'
import ListItemText from '@material-ui/core/ListItemText'
import { createStyles } from '@material-ui/core/styles'
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from 'clsx'
import { useObserver } from 'mobx-react-lite'
import React, { FC, ReactNode } from 'react'
import { CardActionsPlaceHolder } from '../CardActionsBar'
import SelectableComponent, {
  ISelectableComponentProps,
} from '../SelectableCard'
import { withStylesAui } from '../styles'
import type { AuiStandardProps } from '../types'

export type DataCardClassKey = 'listItem' | 'selectable' | 'selected'
export type DataCardClasses = Partial<ClassNameMap<DataCardClassKey>>
const styles = createStyles<DataCardClassKey, any>({
  listItem: {
    display: 'block',
    position: 'relative',
  },
  selectable: {
    position: 'relative',
  },
  selected: {
    pointerEvents: 'none',
  },
})

interface IProps
  extends ISelectableComponentProps,
    AuiStandardProps<DataCardClassKey> {
  onClick?: VoidFunction
  actions?: ReactNode
  icon?: ReactNode
  primaryText?: ReactNode
  secondaryAction?: ReactNode
  secondaryText?: ReactNode
  classes?: DataCardClasses
  color?: PropTypes.Color
}

export const DataCardBase: FC<IProps> = ({
  actions,
  icon,
  primaryText,
  secondaryAction,
  secondaryText,
  selected,
  isSelectable,
  classes = {},
  className,
  color,
  ...rest
}) => {
  return useObserver(() => (
    <SelectableComponent
      isSelectable={isSelectable}
      selected={selected}
      className={clsx(
        classes.selectable,
        { hasActionsBar: !!actions },
        className,
      )}
      color={color}
    >
      <ListItem
        // button={true as any}
        className={clsx(classes.listItem, {
          [`${classes.selected}`]: selected,
        })}
        {...rest}
      >
        <Box className='MuiButtonBase-root MuiListItem-root MuiListItem-gutters MuiListItem-button"'>
          {icon}

          <ListItemText
            primary={primaryText}
            primaryTypographyProps={{ className: 'AuiDataCard-Typography' }}
            secondary={secondaryText}
            secondaryTypographyProps={{ className: 'AuiDataCard-Typography' }}
          />
        </Box>

        {actions && <CardActionsPlaceHolder />}
      </ListItem>
      {secondaryAction}
      {actions}
    </SelectableComponent>
  ))
}

export const DataCard = withStylesAui(styles, {
  name: 'DataCard',
})(DataCardBase)
export default DataCard

DataCard.defaultProps = {
  button: true,
  dense: true,
  disableGutters: true,
}
