import {
  Dialog as MuiDialog,
  DialogContent,
  DialogProps as MuiDialogProps,
  DialogTitle,
} from '@material-ui/core'
import React, { FC } from 'react'
import ConfirmActions, { IButtonProps } from '../ConfirmActions'

export type TDialogConfirmAction = IButtonProps | string | false

export type TDialogBaseProps = Partial<MuiDialogProps> & {
  confirmAction?: TDialogConfirmAction
}

type InnerDialogProps = TDialogBaseProps & {
  open: boolean
  title?: string
  onClose: () => void
}

export const Dialog: FC<InnerDialogProps> = ({
  confirmAction,
  onClose,
  children,
  id = 'dialog',
  title,
  ...props
}) => {
  let actions = null
  if (confirmAction === undefined) {
    actions = (
      <DialogContent>
        <ConfirmActions onConfirm={onClose} cancelProps={{ hide: true }} />
      </DialogContent>
    )
  } else if (typeof confirmAction === 'string') {
    actions = (
      <DialogContent>
        <ConfirmActions
          onConfirm={onClose}
          confirmProps={{ label: confirmAction }}
          cancelProps={{ hide: true }}
        />
      </DialogContent>
    )
  } else if (confirmAction !== false) {
    actions = (
      <DialogContent>
        <ConfirmActions
          onConfirm={onClose}
          confirmProps={confirmAction}
          cancelProps={{ hide: true }}
        />
      </DialogContent>
    )
  }
  return (
    <MuiDialog
      {...props}
      onClose={onClose}
      aria-labelledby={`${id}-title`}
      aria-describedby={`${id}-description`}
    >
      {title && <DialogTitle id={`${id}-title`}>{title}</DialogTitle>}
      {children}
      {actions}
    </MuiDialog>
  )
}
