import { debounce } from 'lodash'
import React, { FC, useState } from 'react'
import { Dialog as AuiDialog, TDialogBaseProps } from './Dialog'

type TBooleanFunction = () => boolean

interface IDialogUserProps {
  onClose?: TBooleanFunction
  onOpen?: TBooleanFunction
}
export type TDialogComponent = FC<TDialogBaseProps & IDialogUserProps>

export interface IDialogState {
  isOpen: boolean
  openDialog: VoidFunction
  closeDialog: VoidFunction
  Dialog: TDialogComponent
}

export type TUseDialog = (startOpen?: boolean) => IDialogState

export const useDialog: TUseDialog = (startOpen = false) => {
  const [initialOpen, setInitialOpen] = useState(startOpen)
  const [isOpen, setIsOpen] = useState(startOpen)
  let onOpenInner: TBooleanFunction | undefined
  const openDialog: VoidFunction = debounce(
    () => {
      if (!onOpenInner || onOpenInner()) {
        setIsOpen(true)
      }
    },
    300,
    { leading: true, trailing: false },
  )
  let onCloseInner: TBooleanFunction | undefined
  const closeDialog: VoidFunction = debounce(
    () => {
      if (!onCloseInner || onCloseInner()) {
        setIsOpen(false)
      }
    },
    300,
    { leading: true, trailing: false },
  )
  const Dialog: TDialogComponent = ({ onClose, onOpen, ...userProps }) => {
    onOpenInner = onOpen
    onCloseInner = onClose
    if (initialOpen && onOpenInner) {
      setIsOpen(onOpenInner())
      setInitialOpen(false)
    }
    return <AuiDialog open={isOpen} onClose={closeDialog} {...userProps} />
  }
  return { isOpen, openDialog, closeDialog, Dialog }
}
