import Box, { BoxProps } from '@material-ui/core/Box'
import Divider from '@material-ui/core/Divider'
import List from '@material-ui/core/List'
import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction'
import ListItemText from '@material-ui/core/ListItemText'
import ListSubheader from '@material-ui/core/ListSubheader'
import Paper from '@material-ui/core/Paper'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import React, { FC, Fragment, useEffect, useState } from 'react'
import ListItem from '../ListItem'

interface ITitle {
  title?: boolean
}

interface ICount {
  count: number
}

export const DocsLoadingPlaceholder: FC<ITitle & ICount> = ({
  title,
  count,
}) => (
  <PaperListPlaceholder title={title}>
    <ListPlaceholder count={count} />
  </PaperListPlaceholder>
)

const PaperListPlaceholder: FC<ITitle> = ({ title, children }) => (
  <Paper>
    {title && (
      <ListSubheader>
        <TextPlaceholder width="45%" />
      </ListSubheader>
    )}
    {children}
  </Paper>
)

const useStyles = makeStyles<Theme>(theme => {
  return {
    iconPlaceholder: {
      backgroundColor: theme.palette.action.disabledBackground,
      borderRadius: 999,
      display: 'inline-block',
      fontSize: 24,
      height: '1em',
      userSelect: 'none',
      width: '1em',
    },
    textPlaceholder: {
      backgroundColor: theme.palette.action.disabledBackground,
      borderRadius: 999,
      display: 'inline-block',
      height: '1rem',
      marginBottom: theme.spacing(1),
      opacity: 0.25,
    },
  }
})

const IconPlaceholder = () => {
  const classes = useStyles()

  return <Box component="span" className={classes.iconPlaceholder} />
}

const TextPlaceholder = ({ width = '100%' }: BoxProps) => {
  const classes = useStyles()

  return (
    <Box component="span" className={classes.textPlaceholder} width={width} />
  )
}

const ItemPlaceholder = () => (
  <ListItem>
    <ListItemText
      primary={<TextPlaceholder />}
      secondary={<TextPlaceholder width="75%" />}
    />
    <ListItemSecondaryAction>
      <IconPlaceholder />
    </ListItemSecondaryAction>
  </ListItem>
)

const ListPlaceholder: FC<ICount> = ({ count }) => {
  const [items, setItems] = useState(Array(count).fill(ItemPlaceholder))
  useEffect(() => {
    const handle = setTimeout(() => {
      setItems([...items, ItemPlaceholder])
    }, 250)
    return () => {
      clearTimeout(handle)
    }
  })
  return (
    <List>
      {items.map((Placeholder, i) => (
        <Fragment key={`Placeholder${i}`}>
          {i > 0 && <Divider />}
          {<Placeholder />}
        </Fragment>
      ))}
    </List>
  )
}
