import { useObserver } from 'mobx-react-lite'
import React, { FC } from 'react'
import type { IColl, IDoc } from '../../docs'
import type { IDocsCollectionTitleProps } from './DocsCollectionTitle'
import { DocsRoot, IDocRootBaseProps } from './DocsRoot'
import { ExpansionList } from './ExpansionList'
import { TitledList } from './TitledList'

interface IDocViewProps<D extends IDoc, P extends {} = {}> {
  document: D
  className?: string

}

export type DocsView<D extends IDoc, P extends {} = {}> = FC<
  IDocViewProps<D> & P
>

export interface IWrapper {
  wrapper?: 'naked' | 'paper'
}

export type DocsSorter<D> = (docA: D, docB: D) => number

// prettier-ignore
export interface IDocCollectionProps<D extends IDoc, P extends {}> extends
  IDocRootBaseProps<D, P>,
  IWrapper,
  IDocsCollectionTitleProps
{
  collection: IColl<D>
  filter?: (doc: D) => boolean
  sort?: DocsSorter<D>
  collapseHistoryStateKey?: string
  fixedOpen?: boolean
  showEmpty?: boolean
}

export const DocsCollection = <D extends IDoc, P extends {}>({
  collection,
  filter,
  sort,
  collapseHistoryStateKey,
  fixedOpen,
  showEmpty = false,
  docsTitle,
  wrapper = 'paper',
  classes,
  ...rest
}: IDocCollectionProps<D, P>) =>
  useObserver(() => {
    let docs = filter ? collection.docs.filter(filter) : collection.docs
    docs = sort ? docs.slice().sort(sort) : docs
    const show = docs.length || showEmpty
    if (!show) {
      return null
    }
    const child = (
      <DocsRoot<D, P>
        docs={docs}
        hasHeader={!!docsTitle}
        {...rest}
        classes={classes}
      />
    )
    return collapseHistoryStateKey ? (
      <ExpansionList
        docsTitle={docsTitle}
        fixedOpen={fixedOpen}
        collapseHistoryStateKey={collapseHistoryStateKey}
        wrapper={wrapper}
        classes={classes}
      >
        {child}
      </ExpansionList>
    ) : (
      <TitledList docsTitle={docsTitle} wrapper={wrapper} classes={classes}>
        {child}
      </TitledList>
    )
  })

DocsCollection.anyUiName = 'DocsCollection'
