import { withStyles } from '@material-ui/core/styles'
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from 'clsx'
import React, { ComponentType, FC, ReactElement } from 'react'
import ResponsiveTitle from '../../ResponsiveTitle'

export type DocsCollectionTitleClassKey = 'root'
export type DocsCollectionTitleClasses = Partial<
  ClassNameMap<DocsCollectionTitleClassKey>
>

export interface IDocsCollectionTitleProps {
  docsTitle?: string | ReactElement
  className?: string
}

export interface IDocsCollectionTitleComponent
  extends IDocsCollectionTitleProps {
  component?: ComponentType | string
  classes?: DocsCollectionTitleClasses
}

const styles = { root: {} }

const DocsCollectionTitleBase: FC<IDocsCollectionTitleComponent> = ({
  docsTitle: Content,
  component: Component = 'div',
  className,
  classes = {},
}) => {
  return Content && typeof Content === 'string' ? (
    <Component>
      <ResponsiveTitle
        mobile="h6"
        desktop="h5"
        className={clsx('AuiDocsCollectionTitle', classes.root, className)}
      >
        {Content}
      </ResponsiveTitle>
    </Component>
  ) : (
    <>{Content}</>
  )
}

export const DocsCollectionTitle = withStyles(styles, {
  name: 'AuiDocsCollectionTitle',
})(DocsCollectionTitleBase)
