import Divider from '@material-ui/core/Divider'
import List from '@material-ui/core/List'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from 'clsx'
import { useObserver } from 'mobx-react-lite'
import React, { Fragment, ReactNode } from 'react'
import type { IDoc } from '../../docs'
import type { DocsView } from './DocsCollection'

export type DocsRootClassKey =
  | 'root'
  | 'defaultView'
  | 'docsCollectionTitle'
  | 'divider'
export type DocRootClasses = Partial<ClassNameMap<DocsRootClassKey>>

export interface IVariant {
  variant?: 'list' | 'grid'
}

export interface IDocClassesProps {
  classes?: DocRootClasses
}

export interface IDocRootBaseProps<D extends IDoc, P extends {}>
  extends IDocClassesProps,
    IVariant {
  DefaultView: DocsView<D, P>
  ViewProps?: any
  className?: string
  preItems?: ReactNode
}
export interface IDocRootProps<D extends IDoc, P extends {}>
  extends IDocRootBaseProps<D, P> {
  docs: D[]
  hasHeader: boolean
}

const useStyles = makeStyles<Theme>(theme => {
  return {
    grid: {
      display: 'grid',
      gridGap: theme.spacing(1),
      // gridTemplateColumns: 'repeat(2, 1fr)',
    },
    padding: {
      '.wrapper-paper &': {
        padding: 0,
      },
    },
  }
})

export const DocsRoot = <D extends IDoc, P extends {}>({
  docs,
  DefaultView,
  ViewProps,
  hasHeader,
  variant = 'list',
  className,
  classes = {},
  preItems,
}: IDocRootProps<D, P>) => {
  const innerClasses = useStyles()
  return useObserver(() => (
    <List
      component="nav"
      className={clsx(`DocsCollection-${variant}`, `DocsRoot-root`, className)}
      classes={{
        padding: innerClasses.padding,
        root: clsx({ [innerClasses.grid]: variant === 'grid' }, classes.root),
      }}
    >
      {preItems && preItems}
      {docs.map((doc, i) => (
        <Fragment key={doc.id}>
          {variant === 'list' && (hasHeader || i > 0) && (
            <Divider className={classes.divider} />
          )}
          <DefaultView
            document={doc}
            {...(ViewProps ? ViewProps : {})}
            className={clsx(classes.defaultView, `DocsRoot-defaultView`)}
          />
        </Fragment>
      ))}
    </List>
  ))
}
