import Box, { BoxProps } from '@material-ui/core/Box'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from 'clsx'
import React, { FC } from 'react'

export type DocsHeaderClassKey = 'root' | 'gutterBottom'
export type DocsHeaderClasses = Partial<ClassNameMap<DocsHeaderClassKey>>

const useStyles = makeStyles<Theme, {}, DocsHeaderClassKey>(
  theme => ({
    gutterBottom: {
      marginBottom: theme.spacing(1),
    },
    root: {
      alignItems: 'center',
      display: 'flex',
      flexDirection: 'row',
    },
  }),
  { name: 'AuiDocsHeader' },
)

interface IDocsHeaderProps extends BoxProps {
  gutterBottom?: boolean
  classes?: DocsHeaderClasses
}
export const DocsHeader: FC<IDocsHeaderProps> = ({
  children,
  gutterBottom,
  classes: outerClasses = {},
  ...rest
}) => {
  const classes = useStyles(outerClasses)
  return (
    <Box
      className={clsx(classes.root, {
        [classes.gutterBottom]: gutterBottom,
      })}
      {...rest}
    >
      <>{children}</>
    </Box>
  )
}
export default DocsHeader
