import { useObserver } from 'mobx-react-lite'
import React, { FC } from 'react'
import { Grow } from '../Atoms'
import type { IColl, IDoc } from '../docs'
import { DocsCollection } from '../DocsCollection'
import { DocsLoadingPlaceholder } from '../DocsCollection/DocsLoadingPlaceholder'
import { DocsHeader } from '../DocsHeader'
import type { IHeaderButtonProps } from '../HeaderButton/HeaderButton'
import { PageAction } from '../PageAction'

import { PageContent } from '../PageContent'
import type { NumStr } from '../PageContent/PageContent'
import { PageTitle } from '../PageTitle'
import { extractAnyUiElements } from '../utils'
import { InjectEmptyResultSlotContent } from './components/DocsEmptyResultSlot'
import { InjectLoadingSlotContent } from './components/DocsLoading'
import { DocsSlotsProvider } from './components/DocsSlotsProvider'

export interface IDocsLayoutProps {
  collection: IColl<IDoc>
  pageWidth?: NumStr
  action?: IHeaderButtonProps
}

export const DocsLayout: FC<IDocsLayoutProps> = ({
  collection,
  children,
  pageWidth,
}) => {
  const [remainingChildren, elements] = extractAnyUiElements(children, [
    PageAction,
    PageTitle,
    DocsCollection,
  ])
  return useObserver(() => {
    const isLoading = collection.isLoading
    const hasData = collection.hasDocs
    return (
      <DocsSlotsProvider>
        <PageContent width={pageWidth}>
          <DocsHeader gutterBottom>
            {elements.get(PageTitle)}
            <Grow />
            {elements.get(PageAction)}
          </DocsHeader>
          {isLoading ? (
            <InjectLoadingSlotContent>
              <DocsLoadingPlaceholder count={3} />
            </InjectLoadingSlotContent>
          ) : !hasData ? (
            <InjectEmptyResultSlotContent />
          ) : (
            elements.get(DocsCollection)
          )}
          {remainingChildren}
        </PageContent>
      </DocsSlotsProvider>
    )
  })
}
export default DocsLayout
