import MuiDrawer, {
  DrawerClassKey,
  DrawerProps as MuiDrawerProps,
} from '@material-ui/core/Drawer'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import clsx from 'clsx'
import React, { FC } from 'react'
import { FullHeight } from '../Atoms'
import type { AuiStandardProps } from '../types'
import addClassNameToProps from '../utils/addClassNameToProps'

export interface IDrawerProps
  extends AuiStandardProps<DrawerClassKey>,
    MuiDrawerProps {
  appBar?: boolean
}
const useStyles = makeStyles<Theme>(theme => {
  return {
    root: {
      '& .appBarSpacing': {
        [theme.breakpoints.up('sm')]: {
          height: `calc(100% - ${theme.mixins.sizes.tabbar.height}px)`,
          top: `${theme.mixins.sizes.tabbar.height}px`,
        },
      },
      flexShrink: 0,
    },
  }
})

export const Drawer: FC<IDrawerProps> = ({ appBar, children, ...props }) => {
  const classes = useStyles()
  return (
    <MuiDrawer
      classes={{
        paper: clsx({ appBarSpacing: appBar }),
        root: classes.root,
      }}
      {...addClassNameToProps(props, 'Drawer')}
    >
      <FullHeight>{children}</FullHeight>
    </MuiDrawer>
  )
}

export default Drawer
