import { observer } from 'mobx-react-lite'
import React, { FC } from 'react'
import type { IDrawerProps } from '../Drawer/Drawer'
import DrawerItem from '../DrawerItem'
import DrawerList from '../DrawerList'
import DrawerTitle from '../DrawerTitle'
import { useDrawerToggle } from '../DrawerToggle'
import TemporaryDrawer from '../ResponsiveDrawer/TemporaryDrawer'
import ResponsiveTitle from '../ResponsiveTitle'
import { useSlotChildren } from '../slots'
import { drawerSlot } from './components/ContentSlot'
import { DrawerLogoContent } from './components/DrawerLogoSlot'
import { drawerTitleSlot } from './components/TitleSlot'
import { usePathActionSlotChildren } from '../navigation/usePathActionSlotChildren'

export const DrawerLayout: FC<IDrawerProps> = observer(
  (drawerProps: IDrawerProps) => {
    const [open, toggleOpen] = useDrawerToggle()
    const drawerTitle = useSlotChildren(drawerTitleSlot)
    const { actions } = usePathActionSlotChildren(drawerSlot, DrawerItem)
    if (!actions.length) {
      return null
    }
    return (
      <TemporaryDrawer open={open} onClose={toggleOpen} {...drawerProps}>
        {drawerTitle.length ? (
          <DrawerTitle className="Aui-hoverable">
            <DrawerLogoContent />
            <ResponsiveTitle className="AuiTitle SectionHeading DrawerTitle">
              {drawerTitle}
            </ResponsiveTitle>
          </DrawerTitle>
        ) : (
          <></>
        )}
        <DrawerList onClick={toggleOpen}>{actions}</DrawerList>
      </TemporaryDrawer>
    )
  },
)
export default DrawerLayout
// <div className="Aui-hoverable" style={{border: '1px solid red'}}><DrawerLogoContent /></div>
