import MenuIcon from '@material-ui/icons/Menu'
import {useObserver} from 'mobx-react-lite'
import React, {FC, ReactNode} from 'react'
import {AppBackButton} from '../AppBackButton'
import {AppBarMenu} from '../AppLayout'
import {locationStore} from '../navigation'
import {ToolBarIconButton} from '../ToolBarIconButton'
import type {AuiStandardProps} from '../types'
import useDrawerToggle from './useDrawerToggle'


interface IDrawerToggle extends AuiStandardProps {
  children?: ReactNode
}
export const DrawerToggleButton: FC<IDrawerToggle> = ({children, ...rest}) => {
  const [, toggleOpen] = useDrawerToggle()
  return (
    <ToolBarIconButton
      color="inherit"
      aria-label="Open drawer"
      onClick={toggleOpen}
      {...rest}
    >
      {children || <MenuIcon />}
    </ToolBarIconButton>
  )
}

export const DrawerToggle: FC<IDrawerToggle> = props =>
  useObserver(() => (
    <AppBarMenu>
      {locationStore.isAtTopRoute ? <DrawerToggleButton {...props}/> : <AppBackButton hideDesktop={false}/>}
    </AppBarMenu>
  ))
export default DrawerToggle
