import ExpansionPanelMui, {
  ExpansionPanelProps,
} from '@material-ui/core/ExpansionPanel'
import { withStyles } from '@material-ui/core/styles'

import clsx from 'clsx'
import React, { FC } from 'react'
import { useHistoryState } from '../navigation'

const styles = {
  root: {
    // eslint-disable-line
    '&.naked': {
      backgroundColor: 'transparent',
      border: 'none',
      boxShadow: 'none',
    },
  },
}

export interface IExpansionPanelProps extends ExpansionPanelProps {
  collapseHistoryStateKey: string
  fixedOpen?: boolean
  naked?: boolean
}

export const ExpansionPanelBase: FC<IExpansionPanelProps> = ({
  fixedOpen = false,
  collapseHistoryStateKey,
  className,
  naked,
  children,
  ...props
}) => {
  const [expanded, setExpanded] = useHistoryState(
    collapseHistoryStateKey,
    fixedOpen,
  )
  const handleChange = (event: React.ChangeEvent<{}>, newExpanded: boolean) => {
    setExpanded(newExpanded)
  }
  return (
    <ExpansionPanelMui
      expanded={fixedOpen || expanded}
      onChange={handleChange}
      className={clsx('AuiExpansionPanel', { naked }, className)}
      {...props}
    >
      {children}
    </ExpansionPanelMui>
  )
}

export const ExpansionPanel = withStyles(styles, { name: 'MuiExpansionPanel' })(
  ExpansionPanelBase,
)
export default ExpansionPanel
