import Button, { ButtonProps } from '@material-ui/core/Button'
import type { Theme } from '@material-ui/core/styles'
import type { SvgIconProps } from '@material-ui/core/SvgIcon'
import { makeStyles } from '@material-ui/core/styles'
import React, { ComponentType, FC } from 'react'

export interface IHeaderButtonProps extends ButtonProps {
  Icon: ComponentType<SvgIconProps>
  label: string
  onClick: () => void
}

const useStyles = makeStyles<Theme>(theme => ({
  button: {
    flex: '0 0 auto',
    height: 32,
  },
  icon: {
    position: 'relative',
    right: theme.spacing(-1),
  },
}))

export const HeaderButton: FC<IHeaderButtonProps> = ({
  Icon,
  label,
  onClick,
  variant = 'contained',
  color = 'primary',
  ...rest
}) => {
  const classes = useStyles()
  return (
    <Button
      variant={variant}
      color={color}
      className={classes.button}
      onClick={onClick}
      {...rest}
    >
      {label}
      <Icon className={classes.icon} />
    </Button>
  )
}
export default HeaderButton
