import IconButton from '@material-ui/core/IconButton'
import Menu from '@material-ui/core/Menu'
import type { SvgIconProps } from '@material-ui/core/SvgIcon'
import React, { ComponentType, FC, useRef } from 'react'
import {mapPathActions} from '../Action'
import { MenuItem } from '../MenuItem'
import {useToggle} from '../toggle'

export const IconMenu: FC<{ Icon: ComponentType<SvgIconProps> }> = ({
  Icon,
  children,
}) => {
  const [open, toggleOpen] = useToggle(false)
  const anchorEl = useRef(null)
  return (
    <>
      <IconButton
        onClick={toggleOpen}
        buttonRef={anchorEl}
        aria-owns={open ? 'menu-appbar' : undefined}
        aria-haspopup="true"
        color="inherit"
      >
        <Icon />
      </IconButton>
      <Menu
        id="menu-appbar"
        open={open}
        onClose={toggleOpen}
        onClick={toggleOpen}
        anchorEl={anchorEl.current}
        anchorOrigin={{
          horizontal: 'right',
          vertical: 'top',
        }}
        transformOrigin={{
          horizontal: 'right',
          vertical: 'top',
        }}
      >
        {mapPathActions(children, MenuItem)}
      </Menu>
    </>
  )
}
export default IconMenu
