import type { ListItemProps } from '@material-ui/core/ListItem'
import ListItemIcon from '@material-ui/core/ListItemIcon'
import ListItemText from '@material-ui/core/ListItemText'
import MuiMenuItem, { MenuItemProps } from '@material-ui/core/MenuItem'
import React, { FC } from 'react'
import type { IPathAction } from '../Action'
import ListItem from '../ListItem'
import { browserHistory } from '../navigation'

export const navigateToPath = (path: string, root?: boolean) => () =>
  browserHistory.push(root ? '/' : path)

interface IProps extends IPathAction {
  comp: 'list' | 'menu'
  // component: ElementType<ListItemProps>
}

export const NavItem: FC<
  ListItemProps & IProps | MenuItemProps & IProps
> = ({ comp, root, path, Icon, button, children, ...rest }) => {
  const Component = comp === 'list' ? ListItem : MuiMenuItem
  return (
    // @ts-ignore
    <Component onClick={navigateToPath(path, root)} {...rest} button>
      {Icon && (
        <ListItemIcon>
          <Icon />
        </ListItemIcon>
      )}
      <ListItemText primary={children} />
    </Component>
  )
}

export default NavItem