import Box from '@material-ui/core/Box'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import clsx from 'clsx'
import React, { FC } from 'react'
import type { IHiddenProps } from '../Atoms/Hidden'
import type { AuiStandardProps } from '../types'
import addClassNameToProps from '../utils/addClassNameToProps'

export type NumStr = string | number

export interface IPageContentProps extends IHiddenProps {
  width?: NumStr
  grid?: boolean
  gap?: number
}

const useStyles = makeStyles<Theme, IPageContentProps>(theme => ({
  grid: {
    display: 'grid',
    gridGap: ({ gap }) => theme.spacing(gap || 1),
  },
  hidden: {
    display: 'none',
  },
  root: {
    margin: '0 auto',
    width: '100%',
  },
}))

export const PageContent: FC<AuiStandardProps & IPageContentProps> = ({
  hidden,
  grid,
  width,
  gap,
  className,
  ...props
}) => {
  const classes = useStyles({ gap })
  return (
    <Box
      maxWidth={width}
      {...addClassNameToProps(
        props,
        'PageContent',
        clsx(
          classes.root,
          { [classes.hidden]: hidden, [classes.grid]: grid },
          className,
        ),
      )}
    />
  )
}

PageContent.defaultProps = {
  gap: 1,
  grid: false,
  hidden: false,
  width: '400px',
}

export default PageContent
