import BottomNavigation, {
  BottomNavigationProps,
} from '@material-ui/core/BottomNavigation'
import { createStyles, withStyles } from '@material-ui/core/styles'
import { observer } from 'mobx-react-lite'
import React, { FC } from 'react'
import { mapPathActions } from '../../Action'
import { primaryNavSlot } from '../../AppLayout'
import { locationStore } from '../../navigation'
import { usePathActionSlotChildren } from '../../navigation/usePathActionSlotChildren'
import { actionPropsMapper } from './actionPropsMapper'
import BottomNavAction from './BottomNavAction'

const styles = createStyles({
  root: {
    bottom: 0,
    flexGrow: 1,
    position: 'fixed',
    width: '100%',
  },
})

const BottomNavBase: FC<Partial<BottomNavigationProps>> = observer(props => {
  const { actions, paths } = usePathActionSlotChildren(
    primaryNavSlot,
    BottomNavAction,
  )
  if (!actions.length) {
    return null
  }
  const selectedPath =
    paths.find(p => p === locationStore.currentTopRoutePath) || false
  return (
    <BottomNavigation {...props} value={selectedPath} showLabels>
      {mapPathActions(actions, BottomNavAction, actionPropsMapper)}
    </BottomNavigation>
  )
})

export const BottomNav = withStyles(styles, { name: 'MuiBottomNavigation' })(
  BottomNavBase,
)
