import Tabs, { TabsProps } from '@material-ui/core/Tabs'
import { withStyles } from '@material-ui/core/styles'
import { observer } from 'mobx-react-lite'
import React, { FC } from 'react'
import { mapPathActions } from '../../Action'
import { primaryNavSlot } from '../../AppLayout'
import { locationStore } from '../../navigation'
import { usePathActionSlotChildren } from '../../navigation/usePathActionSlotChildren'
import { actionPropsMapper } from './actionPropsMapper'
import TopNavAction from './TopNavAction'

const styles = {
  root: {
    flexGrow: 1,
  },
}
interface ITopNavProps extends Partial<TabsProps> {}
const TopNavBase: FC<ITopNavProps> = observer(props => {
  const { actions, paths } = usePathActionSlotChildren(
    primaryNavSlot,
    TopNavAction,
  )
  if (!actions.length) {
    return null
  }
  const selectedPath =
    paths.find(p => p === locationStore.currentTopRoutePath) || false
  return (
    <Tabs
      value={selectedPath}
      indicatorColor="primary"
      textColor="primary"
      {...props}
    >
      {mapPathActions(actions, TopNavAction, actionPropsMapper)}
    </Tabs>
  )
})

export const TopNav = withStyles(styles, { name: 'MuiTabs' })(TopNavBase)
