import type { Variant } from '@material-ui/core/styles/createTypography'
import Typography, { TypographyProps } from '@material-ui/core/Typography'
import { withStyles } from '@material-ui/core/styles'
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from 'clsx'
import React, { FC, ReactNode } from 'react'
import { Visible } from '../Visibility'

export type ResponsiveTitleClassKey = 'root'
export type ResponsiveTitleClasses = Partial<
  ClassNameMap<ResponsiveTitleClassKey>
>

export interface IResponsiveTitleProps {
  desktop?: Variant
  mobile?: Variant
  className?: string
  classes?: ResponsiveTitleClasses
  children?: ReactNode | string
  gutterBottom?: boolean
}

const styles = { root: {} }

export const ResponsiveTitleBase: FC<TypographyProps &
  IResponsiveTitleProps> = ({
  mobile = 'h5',
  desktop = 'h4',
  className,
  classes = {},
  ...props
}) => {
  const rootClassName = clsx('AuiResponsiveTitle', classes.root, className)
  return (
    <>
      <Visible.Mobile>
        <Typography
          variant={mobile}
          {...props}
          classes={{ [mobile]: rootClassName }}
        />
      </Visible.Mobile>
      <Visible.Desktop>
        <Typography
          variant={desktop}
          {...props}
          classes={{ [desktop]: rootClassName }}
        />
      </Visible.Desktop>
    </>
  )
}
export const ResponsiveTitle = withStyles(styles, {
  name: 'AuiResponsiveTitle',
})(ResponsiveTitleBase)

export default ResponsiveTitle
