import type { PropTypes } from "@material-ui/core";
import Card from "@material-ui/core/Card";
import { createStyles, fade, Theme } from "@material-ui/core/styles";
import type { ClassNameMap } from "@material-ui/core/styles/withStyles";
import clsx from "clsx";
import React, { FC } from "react";
import { withStylesAui } from "../styles";
import type { AuiStandardProps } from "../types";
import { capitalize } from "../utils/helpers";

export type SelectableComponentClassKey =
  | 'root'
  | 'deselected'
  | 'selected'
  | 'selectable'
  | 'colorInherit'
  | 'colorDefault'
  | 'colorPrimary'
  | 'colorSecondary'

export type SelectableComponentClassNames = ClassNameMap<
  SelectableComponentClassKey
>

// eslint-disable
const styles = (theme: Theme) =>
  createStyles<SelectableComponentClassKey, any>({
    root: {},
    deselected: {},
    selected: {
      background: theme.palette.action.selected,
    },
    selectable: {},
    colorInherit: {},
    colorDefault: {},
    colorPrimary: {
      color: theme.palette.primary.main,
      backgroundColor: fade(
        theme.palette.primary.main,
        theme.palette.action.hoverOpacity,
      ),
      '&.inverse': {
        backgroundColor: fade(
          theme.palette.secondary.main,
          theme.palette.action.hoverOpacity,
        ),
      },
    },
    colorSecondary: {
      color: theme.palette.secondary.main,
      backgroundColor: fade(
        theme.palette.secondary.main,
        theme.palette.action.hoverOpacity,
      ),
      '&.inverse': {
        backgroundColor: fade(
          theme.palette.primary.main,
          theme.palette.action.hoverOpacity,
        ),
      },
    },
  })

export interface ISelectableComponentProps {
  selected?: boolean
  isSelectable?: boolean
}
interface IProps
  extends ISelectableComponentProps,
    AuiStandardProps<SelectableComponentClassKey> {
  classes?: SelectableComponentClassNames
  color?: PropTypes.Color
}

const SelectableComponentBase: FC<IProps> = ({
  className,
  selected,
  isSelectable,
  classes: outerClasses,
  color,
  ...rest
}) => {
  const classes = outerClasses!
  return (
    <Card
      className={clsx(
        classes.root,
        {
          [classes.deselected]: !selected,
          // @ts-ignore
          [classes[`color${capitalize(color)}`]]: color !== 'default',
          [classes.selectable]: isSelectable,
          'Aui-Selectable': isSelectable,
          [classes.selected]: selected,
          'Mui-selected': selected,
        },
        className,
      )}
      {...rest}
    />
  )
}

export const SelectableComponent = withStylesAui(styles, {
  name: 'SelectableComponent',
})(SelectableComponentBase)
export default SelectableComponent

SelectableComponent.defaultProps = {
  color: 'default',
  isSelectable: false,
  selected: false,
}
