import React, { FC } from 'react'
import { Route, RouteProps } from 'react-router'
import type { ISelectableComponentProps } from '../SelectableCard'

interface ISelectableRoute extends Pick<RouteProps, 'path' | 'exact'> {
  component?: React.ComponentType<ISelectableComponentProps>
  children?: React.Component<ISelectableComponentProps>
}

export const DisabledRoute: FC<ISelectableRoute & any> = ({
  path,
  exact,
  component: Component,
  children,
  ...props
}) => {

  return (
    <Route
      path={path}
      exact={exact}
      children={({ match }) => {
        const disabled = !!match
        if (Component) {
          return <Component {...props} disabled={disabled} />
        } else {
          return React.cloneElement(React.Children.only(children), {
            ...props,
            disabled,
          })
        }
      }}
    />
  )
}
