import React, {FC} from 'react'
import {Route, RouteChildrenProps, RouteProps} from 'react-router'
import type {ISelectableComponentProps} from '../SelectableCard'

interface ISelectableRoute extends Pick<RouteProps, 'path' | 'exact'> {
  component?: React.ComponentType<ISelectableComponentProps>
  children?: React.Component<ISelectableComponentProps>
}

export const SelectableRoute: FC<ISelectableRoute & any> = ({
  path,
  exact,
  component: Component,
  children,
  ...props
}) => {
  const childFunc = ({ match }: RouteChildrenProps) => {
    const selected = !!match
    if (Component) {
      return (
        <Component {...props} selected={selected} isSelectable />
      )
    } else {
      const child = React.Children.only(children)
      return React.cloneElement(child, {
        ...props,
        className: child.props.className,
        isSelectable: true,
        selected,
      })
    }
  }
  return (
    <Route
      path={path}
      exact={exact}
      children={childFunc}
    />
  )
}
export default SelectableRoute