import { createMuiTheme } from '@material-ui/core/styles'
import type { ThemeOptions } from '@material-ui/core/styles/createMuiTheme'
import {
  // CreateCSSProperties,
  // CSSProperties,
  ThemeProvider as MuiThemeProvider,
} from '@material-ui/core/styles'
import type { CreateCSSProperties, CSSProperties } from "@material-ui/styles";
import React from 'react'
import type { CardSecondaryActionClassKey } from '../CardSecondaryAction/CardSecondaryAction'
import type { DocsCollectionTitleClassKey } from '../DocsCollection/components/DocsCollectionTitle'
import type { DocsHeaderClassKey } from '../DocsHeader/DocsHeader'
import type { ResponsiveTitleClassKey } from '../ResponsiveTitle/ResponsiveTitle'
import type { SelectableComponentClassKey } from '../SelectableCard'

import type { NamedAnyUiComponent } from '../utils'

export interface IThemeProvider {
  themeOptions?: ThemeOptions
}

export type TStylesOverride<P extends object = {}> =
  | CSSProperties
  | ((props: P) => CreateCSSProperties<P>)

export type TStylesGenerator<P extends object = {}> = (
  override?: TStylesOverride<P>,
) => (props: P) => CreateCSSProperties<P>

declare module '@material-ui/core/styles/overrides' {
  // eslint-disable-line @typescript-eslint/interface-name-prefix
  interface ComponentNameToClassKey {
    AuiSelectableComponent: SelectableComponentClassKey
    AuiDocsHeader: DocsHeaderClassKey
    AuiDocsCollectionTitle: DocsCollectionTitleClassKey
    AuiResponsiveTitle: ResponsiveTitleClassKey
    AuiCardSecondaryAction: CardSecondaryActionClassKey
  }
}

declare module '@material-ui/core/styles/createMixins' {
  export interface ISize {
    height?: number
  }

  // eslint-disable-line @typescript-eslint/interface-name-prefix
  interface Mixins {
    sizes: {
      bottomNav: ISize
      tabbar: ISize
      toolbar: ISize
    }
  }
}

export const ThemeProvider: NamedAnyUiComponent<IThemeProvider> = ({
  themeOptions = {},
  children,
}) => {
  const theme = createMuiTheme({
    mixins: {
      sizes: {
        bottomNav: {
          height: 56,
        },
        tabbar: {
          height: 72,
        },
        toolbar: {
          height: 64,
        },
      },
    },
    ...themeOptions,
  })
  return <MuiThemeProvider theme={theme}>{children}</MuiThemeProvider>
}
ThemeProvider.anyUiName = 'ThemeProvider'
export default ThemeProvider
