import MuiIconButton, { IconButtonProps } from '@material-ui/core/IconButton'
import type { Theme } from '@material-ui/core/styles'
import { makeStyles } from '@material-ui/core/styles'
import clsx from 'clsx'
import React, { FC } from 'react'
import addClassNameToProps from '../utils/addClassNameToProps'

export interface IToolBarIconButtonProps extends IconButtonProps {
  hideDesktop?: boolean
  direction?: 'ltr' | 'rtl'
}

const useStyles = makeStyles<Theme>(theme => {
  return {
    root: {
      '&.hide': {
        [theme.breakpoints.up('sm')]: {
          display: 'none',
        },
      },
      '&.root.ltr': {
        marginRight: theme.spacing(1),
      },
      '&.root.rlt': {
        marginLeft: theme.spacing(1),
      },
    },
  }
})

export const ToolBarIconButton: FC<IToolBarIconButtonProps> = ({
  hideDesktop,
  direction = 'ltr',
  ...props
}) => {
  const classes = useStyles()
  return (
    <MuiIconButton
      classes={{
        root: clsx('root', classes.root, { hide: hideDesktop }, direction),
      }}
      {...addClassNameToProps(props, 'ToolBarIconButton Aui-hoverable')}
    />
  )
}
export default ToolBarIconButton
