import flatten from "lodash/flatten";
import type { IColl } from "./IColl";

export class Coll<D> implements IColl<D> {
  public get hasDocs(): boolean {
    return this.docs.length > 0;
  }

  public static filter<D>(
    collection: IColl<D>,
    callbackfn: (p: D) => boolean
  ): IColl<D> {
    return new Coll(collection.docs.filter(callbackfn));
  }

  public static flatMap<D, A>(
    collection: IColl<D>,
    callbackfn: (p: D) => A[]
  ): IColl<A> {
    return new Coll(flatten(collection.docs.map(callbackfn)));
  }

  public static of<D>(docs: D[]): IColl<D> {
    return new Coll(docs);
  }

  public readonly isLoading: boolean = false;

  constructor(public readonly docs: D[]) {}
}
export default Coll;
