import { computed, observable } from 'mobx'
import {
  fromPromise,
  FULFILLED,
  IPromiseBasedObservable,
  PENDING,
} from 'mobx-utils'

import type { IColl, IDoc } from '../docs'

/**
 * An HttpsCallableResult wraps a single result from a function call.
 */
// eslint-disable-line @typescript-eslint/interface-name-prefix
export interface HttpsCallableResult {
  readonly data: any;
}

export class HttpsCallableCollAdapter<D extends IDoc> implements IColl<D> {
  @observable
  private promise: IPromiseBasedObservable<
    HttpsCallableResult
  >

  constructor(
    private readonly promiseFactory: () => Promise<
      HttpsCallableResult
    >,
    private readonly mapper: (dataElement: any) => D,
  ) {
    this.promise = fromPromise(this.promiseFactory())
  }

  public reload() {
    this.promise = fromPromise(this.promiseFactory(), this.promise)
  }

  @computed
  get isLoading(): boolean {
    return this.promise.state === PENDING
  }

  @computed
  get hasDocs(): boolean {
    return !!this.docs.length
  }

  @computed
  get docs(): D[] {
    if (this.promise.state !== FULFILLED) {
      return []
    }
    return this.promise.value.data.map(this.mapper)
  }
}
export default HttpsCallableCollAdapter
