import type { Location } from 'history'
import { useCallback, useEffect, useState } from 'react'
import { browserHistory } from './navigation'

export type SetValue<S> = (newValue: S) => void
export type State<S> = [S, SetValue<S>]

export function useHistoryState<S>(key: string, initialValue: S): State<S> {
  const defaultValue = useCallback(
    (location: Location<any>): S =>
      location.state && key in location.state
        ? location.state[key]
        : initialValue,
    [key, initialValue],
  )
  const [value, setLocalState] = useState(() =>
    defaultValue(browserHistory.location),
  )
  useEffect(
    () =>
      browserHistory.listen((location: Location) => {
        setLocalState(defaultValue(location))
      }),
    [defaultValue],
  )
  const setState: SetValue<S> = newValue => {
    browserHistory.replace({
      ...browserHistory.location,
      state: { ...(browserHistory.location.state || {}), [key]: newValue },
    })
  }
  return [value, setState]
}
