import { observer } from 'mobx-react-lite'
import React, { FC, isValidElement, useContext } from 'react'
import type { SlotContext } from './createSlot'

export interface ISlotContentProps {
  slot: SlotContext
  name?: string
}

export const SlotContent: FC<ISlotContentProps> = observer(
  ({ slot: slotContext, name, children }): any => {
    const slot = useContext(slotContext)
    if (!slot) {
      throw new Error(
        `Null slot (${name ||
          'un-named'}), have you forgotten to use provider?`,
      )
    }
    const slotChild = slot.child
    if (!slotChild) {
      return typeof children === 'function' ? children() : <>{children}</>
    }
    const content = isValidElement(slotChild) ? slotChild : <>{slotChild}</>
    return typeof children === 'function' ? children(content) : content
  },
)
