import { useRef } from 'react'

const arraysShallowEqual = (a: any[], b: any[]): boolean => {
  if (a.length !== b.length) {
    return false
  }
  for (let i = 0; i < a.length; i += 1) {
    if (!Object.is(a[i], b[i])) {
      return false
    }
  }
  return true
}

export function useDerivedState<T>(factory: () => T, deps: any[] = []): T {
  const prevDepsRef = useRef<any[]>([])
  const storeRef = useRef<T | null>(null)
  if (!storeRef.current || !arraysShallowEqual(prevDepsRef.current, deps)) {
    storeRef.current = factory()
    prevDepsRef.current = deps
  }
  return storeRef.current
}

export const useStoreClass = <C extends new (...args: any[]) => any>(
  StoreClass: C,
  ...args: ConstructorParameters<C>
): InstanceType<C> => useDerivedState(() => new StoreClass(...args), args)
